@@ -287,6 +287,11 @@ bool Molec::printspecies(std::ostream & o, bool first) const{
   return first;
 }
 
+void Molec::delete_aq(){
+  // retire les attributs aqueux
+  if (t==aqueous_explicit) t=aqueous;
+}
+
 void Molec::printnorm(std::ostream & o)const{
   if (nb!=1) o << nb << " ";
   al-> printnorm(o);
@@ -502,6 +507,13 @@ void Membre::numerote(){
   }
 }
 
+void Membre::delete_aq(){
+  // retire les attributs aqueux
+  for (unsigned int i=0; i < size(); i++){
+    operator [](i)->delete_aq();
+  }  
+}
+
 void Membre::triage(){
   unsigned int i,j;
   for (i=0; i < size(); i++){
@@ -780,6 +792,12 @@ void Chemeq::coeff1(){
   }
 }
 
+void Chemeq::delete_aq(){
+  // supprime tous les attributs "aqueux" des molécules ou ions présents
+  gauche->delete_aq();
+  droit->delete_aq();
+}
+
 void Chemeq::multiply(int num, int den){
   fraction mult(num,den);
   gauche->coeff(mult);
